@@ -30,24 +30,31 @@
 
 #include <libmatewnck/libmatewnck.h>
 
+#include <gio/gio.h>
 #include <mate-panel-applet.h>
-#include <mate-panel-applet-mateconf.h>
-#include <mateconf/mateconf-client.h>
+#include <mate-panel-applet-gsettings.h>
 
 #include "task-list.h"
 #include "task-title.h"
 
-#define SHOW_WIN_KEY "show_all_windows"
+#define APPLET_SCHEMA "org.mate.panel.applet.mate-window-picker-applet"
+#define SHOW_WIN_KEY "show-all-windows"
+
+#define MAXIMUS_SCHEMA "org.mate.maximus"
+#define UNDECORATE_KEY "undecorate"
+#define NO_MAXIMIZE_KEY "no-maximize"
 
 typedef struct 
 {
   GtkWidget    *tasks;
   GtkWidget    *applet;
   GtkWidget    *title;
+  GSettings    *settings;
   
 } WinPickerApp;
 
 static WinPickerApp *mainapp;
+static gpointer parent_class;
 
 static void cw_panel_background_changed (MatePanelApplet               *applet,
                                          MatePanelAppletBackgroundType  type,
@@ -64,7 +71,7 @@ static const GtkActionEntry window_picker_menu_actions [] = {
 	{ "MenuPrefs", GTK_STOCK_PREFERENCES, N_("_Preferences"),
       NULL, NULL,
       G_CALLBACK (display_prefs_dialog) },
-	{ "ShowDesktopAbout", GTK_STOCK_ABOUT, N_("_About"),
+	{ "MenuAbout", GTK_STOCK_ABOUT, N_("_About"),
       NULL, NULL,
       G_CALLBACK (display_about_dialog) }
 };
@@ -76,9 +83,8 @@ static const gchar *close_window_authors [] = {
 };
 
 static void
-on_show_all_windows_changed (MateConfClient *client,
-                             guint        conn_id,
-                             MateConfEntry  *entry,
+on_show_all_windows_changed (GSettings   *settings,
+                             gchar       *key,
                              gpointer     data)
 {
   WinPickerApp *app;
@@ -86,8 +92,7 @@ on_show_all_windows_changed (MateConfClient *client,
 
   app = (WinPickerApp*)data;
 
-  show_windows = mate_panel_applet_mateconf_get_bool (MATE_PANEL_APPLET (app->applet),
-                                              SHOW_WIN_KEY, NULL);
+  show_windows = g_settings_get_boolean (settings, SHOW_WIN_KEY);
 
   g_object_set (app->tasks, "show_all_windows", show_windows, NULL);
 }
@@ -114,6 +119,20 @@ force_no_focus_padding (GtkWidget *widget)
   gtk_widget_set_name (widget, "na-tray");
 }
 
+static void
+cw_applet_finalize (GObject *object)
+{
+  /* disable Maximus */
+  GSettings *maximus_settings;
+  maximus_settings = g_settings_new (MAXIMUS_SCHEMA);
+  g_settings_set_boolean (maximus_settings, UNDECORATE_KEY, FALSE);
+  g_settings_set_boolean (maximus_settings, NO_MAXIMIZE_KEY, TRUE);
+  g_object_unref (maximus_settings);
+
+  if (G_OBJECT_CLASS (parent_class)->finalize)
+    (* G_OBJECT_CLASS (parent_class)->finalize) (object);
+}
+
 static gboolean
 cw_applet_fill (MatePanelApplet *applet, 
                 const gchar *iid, 
@@ -122,10 +141,9 @@ cw_applet_fill (MatePanelApplet *applet,
   MatewnckScreen *screen;
   WinPickerApp *app;
   GtkWidget *eb, *tasks, *title;
-  GError *error = NULL;
-  gchar *key;
   gchar *ui_path;
   GtkActionGroup *action_group;
+  GObjectClass *object_class;
   
   if (strcmp (iid, "MateWindowPicker") != 0)
 		return FALSE;
@@ -140,21 +158,22 @@ cw_applet_fill (MatePanelApplet *applet,
   mainapp = app;
   screen = matewnck_screen_get_default ();
 
-  /* mateconf prefs */
-  mate_panel_applet_add_preferences (applet, 
-                                "/schemas/apps/mate-window-picker-applet/prefs",
-                                &error);
-  if (error)
-  {
-    g_warning ("%s", error->message);
-    g_error_free (error);
-  }
+  /* prepare to disable Maximus */
+  object_class = G_OBJECT_GET_CLASS (G_OBJECT(applet));
+  object_class->finalize = cw_applet_finalize;
+  parent_class = g_type_class_peek_parent (object_class);
 
-  key = mate_panel_applet_mateconf_get_full_key (applet, SHOW_WIN_KEY);
-  mateconf_client_notify_add (mateconf_client_get_default (), key,
-                           on_show_all_windows_changed, app,
-                           NULL, NULL);
-  g_free (key);
+  /* enable Maximus */
+  GSettings *maximus_settings;
+  maximus_settings = g_settings_new (MAXIMUS_SCHEMA);
+  g_settings_set_boolean (maximus_settings, UNDECORATE_KEY, TRUE);
+  g_settings_set_boolean (maximus_settings, NO_MAXIMIZE_KEY, FALSE);
+  g_object_unref (maximus_settings);
+
+  /* gsettings prefs */
+  app->settings = mate_panel_applet_settings_new (applet, APPLET_SCHEMA);
+  g_signal_connect (app->settings, "changed::" SHOW_WIN_KEY,
+                    G_CALLBACK (on_show_all_windows_changed), app);
 
   app->applet = GTK_WIDGET (applet);
   force_no_focus_padding (GTK_WIDGET (applet));
@@ -172,7 +191,7 @@ cw_applet_fill (MatePanelApplet *applet,
 
   gtk_widget_show_all (GTK_WIDGET (applet));
 	
-  on_show_all_windows_changed (NULL, 0, NULL, app);
+  on_show_all_windows_changed (app->settings, SHOW_WIN_KEY, app);
 		
   /* Signals */
 	g_signal_connect (applet, "change-background",
@@ -185,7 +204,7 @@ cw_applet_fill (MatePanelApplet *applet,
                                   window_picker_menu_actions,
                                   G_N_ELEMENTS (window_picker_menu_actions),
                                   app);
-    ui_path = g_build_filename (MATEWINDOWPICKER_MENU_UI_DIR, "mate-window-picker-menu.xml", NULL);
+    ui_path = g_build_filename (MATEWINDOWPICKER_MENU_UI_DIR, "mate-window-picker-applet-menu.xml", NULL);
     mate_panel_applet_setup_menu_from_file (MATE_PANEL_APPLET (app->applet),
                                        ui_path, action_group);
     g_free (ui_path);
@@ -267,8 +286,9 @@ display_about_dialog (GtkAction       *action,
                 "comments", _("Window Picker"),
                 "version", PACKAGE_VERSION,
                 "authors", close_window_authors,
-                "logo-icon-name", "system-preferences-windows",
-                "copyright", "Copyright \xc2\xa9 2008 Canonical Ltd",
+                "logo-icon-name", "preferences-system-windows",
+                "copyright", "Copyright \xc2\xa9 2008 Canonical Ltd\n"
+                             "Copyright \xc2\xa9 2013 Stefano Karapetsas",
                 NULL);
 
   gtk_widget_show (panel_about_dialog);
@@ -287,8 +307,7 @@ on_checkbox_toggled (GtkToggleButton *check, gpointer null)
     
   is_active = gtk_toggle_button_get_active (check);
 
-  mate_panel_applet_mateconf_set_bool (MATE_PANEL_APPLET (mainapp->applet),
-                                              SHOW_WIN_KEY, is_active, NULL);
+  g_settings_set_boolean (mainapp->settings, SHOW_WIN_KEY, is_active);
 }
 
 static void
@@ -317,9 +336,7 @@ display_prefs_dialog (GtkAction       *action,
   check = gtk_check_button_new_with_label (_("Show windows from all workspaces"));
   gtk_box_pack_start (GTK_BOX (vbox), check, FALSE, TRUE, 0);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
-                                mate_panel_applet_mateconf_get_bool (
-                                              MATE_PANEL_APPLET (mainapp->applet),
-                                              SHOW_WIN_KEY, NULL));
+                                g_settings_get_boolean (mainapp->settings, SHOW_WIN_KEY));
   g_signal_connect (check, "toggled",
                     G_CALLBACK (on_checkbox_toggled), NULL);
 
